%% script for generating the Pareto Front for Fermat-Weber problem (Sec 4.2)
    clear 
    rng(123)

    n = 2; m = 2; p = 5;
    r = 300;
    tol = 1e-8;
    maxit = 1000;
    
    [Ac, P, a0] = chmp_easy(m,n,p);
    %[Ac, P, a0] = chmp_hard(m,n,p);
    
    h1 = figure(1);
    hold on
    h2 = figure(2);
    hold on
    h3 = figure(3);
    hold on
    
     %% image of the feasible set
%    h4 = figure(4);
%    hold on
%     for i=1:20000
%         w = rand(p,1);
%         a0 = projsplx(w); % projects onto unit simplex
%         
%         F = fermat(Ac*a0, P);
%         f10 = F(1);
%         f20 = F(2);
%         
%         plot(f10,f20,'k.');
%         
%     end
    
    %% running from different starting points
    k1 = [];
    k2 = [];
    k3 = [];

    for i=1:r
        w = rand(p,1);
        a0 = projsplx(w);
        
        F = fermat(Ac*a0, P);
        f10 = F(1);
        f20 = F(2);
    
        % M-FW
        [x,F,k,fe,flag] = ASFW(@(x) fermat(x,P), 1, Ac, a0, tol, maxit, 0, 1);
        
        k1 = [k1; k];
        
        f1s = F(1);
        f2s = F(2);
        
        if f1s > f10 || f2s > f20
            error('... something went wrong !!!')
        end
        
        figure(h1)
        plot([f10 f1s],[f20 f2s],'.-','Color',[0.5 0.5 0.5]);
        if flag < 0
            plot(f1s,f2s,'kx');
        else
            plot(f1s,f2s,'ko');
        end
        
        % M-AFW
        [x,F,k,fe,flag] = ASFW(@(x) fermat(x,P), 1, Ac, a0, tol, maxit, 1, 1);
        
        k2 = [k2; k];
        
        f1s = F(1);
        f2s = F(2);
        
        if f1s > f10 || f2s > f20
            error('... something went wrong !!!')
        end
        
        figure(h2)
        plot([f10 f1s],[f20 f2s],'.-','Color',[0.5 0.5 0.5]);  
        plot(f1s,f2s,'ks');
        
        % CSD
        [x,F,k,fe,flag] = CSD(@(x) fermat(x,P), 1, Ac, a0, tol, maxit);
        
        k3 = [k3; k];
        
        f1s = F(1);
        f2s = F(2);
        
        if f1s > f10 || f2s > f20
            error('... something went wrong !!!')
        end
        
        figure(h3)
        plot([f10 f1s],[f20 f2s],'.-','Color',[0.5 0.5 0.5]);  
        plot(f1s,f2s,'ks');
    
    end

