%% script for generating the Pareto Front for Fermat-Weber problem (Sec 4.2)
    clear 
    rng(123)

    m = 2; n = 10;
    p = 2*n;
    r = 10; % 300;
    tol = 1e-8;
    maxit = 5000;
    
    Ac = [-eye(n) eye(n)];
    A = cell(m,1);
    B = zeros(n,m);
    L = 0;
    
    for l=1:m
       
       D = diag(abs(10*randn(n,1)));
       if max(diag(D))^2 > L
           L = max(diag(D))^2; 
       end
       
       A{l} = D; % diagonal positive definite
       
       xs = rand(n,1);
       idx = randi(n);
       xs(idx) = 0; % unconstrained minimizer of each objective outside ||x||_1 <= 1
       xs(idx) = (1 - sum(xs));
       B(:,l) = A{l}*xs;
   end
    
    h1 = figure(1);
    hold on
    h2 = figure(2);
    hold on
    h3 = figure(3);
    hold on
    
     %% image of the feasible set
%    h4 = figure(4);
%    hold on
%     for i=1:20000
%         
%         w = rand(2*n,1);
%         a0 = projsplx(w);
%         a0 = max(a0,0);
%         a0 = a0./sum(a0);
%         
%         x = Ac*a0;
%         
%         F = toyfunG(x,A,B,n,m);
%         f10 = F(1);
%         f20 = F(2);
%         
%         plot(f10,f20,'k.');
%         
%     end
    
    %% running from different starting points
    k1 = [];
    k2 = [];
    k3 = [];

    for i=1:r
        w = rand(p,1);
        a0 = projsplx(w);
        
        F = toyfunG(Ac*a0,A,B,n,m);
        f10 = F(1);
        f20 = F(2);
    
        % M-FW
        [x,F,k,fe,flag1] = ASFW(@(x) toyfunG(x,A,B,n,m), L, Ac, a0,tol,2000,0,0);
        
        k1 = [k1; k];
        
        f1s = F(1);
        f2s = F(2);
        
        if f1s > f10 || f2s > f20
            error('... something went wrong !!!')
        end
        
        figure(h1)
        plot([f10 f1s],[f20 f2s],'.-','Color',[0.5 0.5 0.5]);
        if flag < 0
            plot(f1s,f2s,'kx');
        else
            plot(f1s,f2s,'ko');
        end
        
        % M-AFW
        [x,F,k,fe,flag2] = ASFW(@(x) toyfunG(x,A,B,n,m), L, Ac, a0,tol,2000,1,0);
        
        k2 = [k2; k];
                
        f1s = F(1);
        f2s = F(2);
        
        if f1s > f10 || f2s > f20
            error('... something went wrong !!!')
        end
        
        figure(h2)
        plot([f10 f1s],[f20 f2s],'.-','Color',[0.5 0.5 0.5]);  
        plot(f1s,f2s,'ks');
        
        % CSD
        tic;
        [x,F,k,fe,flag3,~,tstop] = CSD(@(x) toyfunG(x,A,B,n,m), L, Ac, a0, tol, 2000);
        toc;
        
        k3 = [k3; k];
        
        f1s = F(1);
        f2s = F(2);
        
        if f1s > f10 || f2s > f20
            error('... something went wrong !!!')
        end
        
        figure(h3)
        plot([f10 f1s],[f20 f2s],'.-','Color',[0.5 0.5 0.5]);  
        plot(f1s,f2s,'ks');
    
    end

